@@ -7,6 +7,7 @@ use deno_ast::swc::visit::noop_visit_type;
 use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::{VisitAll, VisitAllWith};
 use derive_more::Display;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoFuncAssign;
@@ -28,8 +29,8 @@ enum NoFuncAssignHint {
 }
 
 impl LintRule for NoFuncAssign {
-  fn new() -> Box<Self> {
-    Box::new(NoFuncAssign)
+  fn new() -> Arc<Self> {
+    Arc::new(NoFuncAssign)
   }
 
   fn tags(&self) -> &'static [&'static str] {
