@@ -11,6 +11,7 @@ use deno_ast::swc::{
   visit::Node,
   visit::{noop_visit_type, Visit, VisitWith},
 };
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoImportAssign;
@@ -20,8 +21,8 @@ const MESSAGE: &str = "Assignment to import is not allowed";
 const HINT: &str = "Assign to another variable, this assignment is invalid";
 
 impl LintRule for NoImportAssign {
-  fn new() -> Box<Self> {
-    Box::new(NoImportAssign)
+  fn new() -> Arc<Self> {
+    Arc::new(NoImportAssign)
   }
 
   fn tags(&self) -> &'static [&'static str] {
