@@ -8,6 +8,7 @@ use deno_ast::swc::common::Span;
 use deno_ast::swc::visit::noop_visit_type;
 use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::Visit;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoInvalidRegexp;
@@ -17,8 +18,8 @@ const MESSAGE: &str = "Invalid RegExp literal";
 const HINT: &str = "Rework regular expression to be a valid";
 
 impl LintRule for NoInvalidRegexp {
-  fn new() -> Box<Self> {
-    Box::new(NoInvalidRegexp)
+  fn new() -> Arc<Self> {
+    Arc::new(NoInvalidRegexp)
   }
 
   fn tags(&self) -> &'static [&'static str] {
