@@ -19,6 +19,7 @@ use derive_more::Display;
 use if_chain::if_chain;
 use std::collections::HashSet;
 use std::iter;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoUnusedVars;
@@ -47,8 +48,8 @@ enum NoUnusedVarsHint {
 }
 
 impl LintRule for NoUnusedVars {
-  fn new() -> Box<Self> {
-    Box::new(NoUnusedVars)
+  fn new() -> Arc<Self> {
+    Arc::new(NoUnusedVars)
   }
 
   fn tags(&self) -> &'static [&'static str] {
