@@ -11,6 +11,7 @@ use deno_ast::swc::ast::YieldExpr;
 use deno_ast::swc::visit::noop_visit_type;
 use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::Visit;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct RequireYield;
@@ -19,8 +20,8 @@ const CODE: &str = "require-yield";
 const MESSAGE: &str = "Generator function has no `yield`";
 
 impl LintRule for RequireYield {
-  fn new() -> Box<Self> {
-    Box::new(RequireYield)
+  fn new() -> Arc<Self> {
+    Arc::new(RequireYield)
   }
 
   fn tags(&self) -> &'static [&'static str] {
